# ci-cd-example

ci-cd-example

CI/CD pipelines for scraper library


## Get started


#### Install requirements & pre-commit hooks

```bash
$ make setup
```

#### Testing
```bash
$ make test
```

#### Documentation

##### Locally

Serve docs locally

```bash
$ make docs-dev
```

##### Build site

```bash
$ make docs-build
```


#### Linters requirements & pre-commit hooks

##### Run flake8

```bash
$ make lint
```

##### Run black & isort

```bash
$ make black
```
